#!/usr/bin/env python

# This script requires Python 2.5 and copies all the files to the right places
# and packs them into ZIP archives.  You can find the theme bundle at
# Dist/iTango.theme and the archives under Dist/Archives.

name = "iTango"		# Theme name
bundle = name		# Bundle name (theme name followed by .theme)

import os, sys, shutil, zipfile

def zipdirtree(src, dst, mode="w", root=""):
	"""zipdirtree(src, dst[, mode[, root]])
Takes a directory tree src and adds it to a ZIP file dst.
Optional params:
mode = open dst with this mode (w to overwrite or a to append; defaults to w)
root = takes this off the left of the filename as it appears in the zip
       (defaults to "")"""
	zip1 = zipfile.ZipFile(dst, mode)
	files = []
	for r, d, f in os.walk(src):
		for n in f:
			files.append(os.path.join(r, n))
	files.sort()
	for i in files:
		if root != "" and i.startswith(root) == True:
			arc = i.split(root, 1)[1].lstrip("/")
			zip1.write(i, arc)
		else:
			zip1.write(i)
	zip1.close()
def zipafile(src, dst, mode="w", root=""):
	"""zipafile(src, dst[, mode[, root]])
Takes a file src and adds it to a ZIP file dst.
Optional params:
mode = open dst with this mode (w to overwrite or a to append; defaults to w)
root = takes this off the left of the filename as it appears in the zip
       (defaults to "")"""
	zip1 = zipfile.ZipFile(dst, mode)
	if root != "" and src.startswith(root) == True:
		arc = src.split(root, 1)[1].lstrip("/")
		zip1.write(src, arc)
	else:
		zip1.write(src)
	zip1.close()
def rmdir_recurse(thedir):
	for r, d, f in os.walk(thedir, topdown=False):
		for n in f:
			os.remove(os.path.join(r, n))
		for n in d:
			os.rmdir(os.path.join(r, n))
	os.rmdir(thedir)

if len(sys.argv) != 2:
	print "Usage: build.py VERSION"
	sys.exit(2)
else:
	version = sys.argv[1]
devroot = "Dev"
distroot = "Dist"
dupefile = os.path.join(devroot, "duplicates")
archiveroot = os.path.join(distroot, "Archives")
bundleroot = os.path.join(distroot, bundle)
bundleiconroot = os.path.join(bundleroot, "Icons")
deviconroot = os.path.join(devroot, "Icons")
devotherroot = os.path.join(devroot, "Other")
devfoldersroot = os.path.join(devroot, "Folders")

# make directories if necessary
if os.path.exists(distroot) == False:
	os.makedirs(distroot, 0755)
	print "Made directory %s" % distroot
if os.path.exists(archiveroot) == False:
	os.makedirs(archiveroot, 0755)
	print "Made directory %s" % archiveroot
if os.path.exists(bundleroot) == True:
	rmdir_recurse(bundleroot)
	print "Removed old bundle root"
if os.path.exists(bundleiconroot) == False:
	os.makedirs(bundleiconroot, 0755)
	print "Made directory %s" % bundleiconroot

execfile(dupefile) # Load list of duplicates

# Start cleaning and copying
#preiconlist1 = os.listdir(bundleiconroot)
#for i in preiconlist1:
#	if i.startswith(".") == False and os.path.isdir(i) != True:
#		os.remove(os.path.join(bundleiconroot, i))
#print "Cleaned out %s" % bundleiconroot

preiconlist2 = os.listdir(deviconroot)
for i in preiconlist2:
	shutil.copy(os.path.join(deviconroot, i), os.path.join(bundleiconroot, i))
print "Copied icons from %s to %s" % (deviconroot, bundleiconroot)

otherlist = []
othermkdirs = []
for r, d, f in os.walk(devotherroot):
	for o in d:
		use = os.path.join(r.split(devotherroot, 1)[1].lstrip("/"), o)
		if os.path.exists(os.path.join(bundleroot, use)) != True:
			os.makedirs(os.path.join(bundleroot, use), 0755)
	for n in f:
		use = os.path.join(r.split(devotherroot, 1)[1].lstrip("/"), n)
		shutil.copy(os.path.join(devotherroot, use), os.path.join(bundleroot, use))
#for i in othermkdirs:
#	os.makedirs(os.path.join(bundleroot, i), 0755)
#for i in otherlist:
#	shutil.copy(os.path.join(devotherroot, i), os.path.join(bundleroot, i))
print "Copied other theme files from %s to %s" % (devotherroot, bundleroot)

print "Copying duplicate icons listed in %s:" % dupefile
iconlist = os.listdir(bundleiconroot)
for i in iconlist:
	k = i.replace(".png", "")
	if k in duplicates:
		for j in duplicates[k]:
			namek = k+".png"
			namej = j+".png"
			shutil.copy(os.path.join(bundleiconroot, namek), os.path.join(bundleiconroot, namej))
			print "    Copied %s to %s" % (namek, namej)
# End cleaning and copying

# make the theme archive
themearcname = os.path.join(archiveroot, "%s-%s.zip" % (name, version))
zipdirtree(bundleroot, themearcname, root="Dist/")
zipafile("install.py", themearcname, mode="a")
print "Made %s containing %s" % (themearcname, bundle)

# make the source archive
srcarcname = os.path.join(archiveroot, "%s-%s_Source.zip" % (name, version))
zipdirtree(devroot, srcarcname)
for i in ["build.py", "install.py", "iTango.png", "iTango_WebClip.png"]:
	zipafile(i, srcarcname, mode="a")
print "Made %s containing source files" % srcarcname
